/**
  * @file   银行图标
  * @since  0.0.21
  * @author Max Chen
  * @module mt-bank-icon
  * @see {@link http://yihuibao.gitee.io/pc_component/dist/docs/#/mt-bank-icon}
  *
  * @arg  Props
  * @arg  Props.icon            {String}
  * @arg  [Props.size='s']      {String}
  * @arg  [Props.color='#666']  {String}
  *
  * @example <caption> icon-picker </caption>
  * <template>
      <el-table :data="list" border>
        <el-table-column
          fixed
          prop="name"
          label="标题"
          width="150">
        </el-table-column>
        <el-table-column
          prop="icon"
          label="预览">
          <template scope="scope">
            <div class="pd-10 ta-c">
              <mt-bank-icon size="30" :icon ="list[scope.$index].icon"></mt-bank-icon>
            </div>
          </template>
        </el-table-column>
        <el-table-column
          prop="icon"
          label="icon">
        </el-table-column>
        <el-table-column
          fixed="right"
          label="操作"
          width="300">
          <template scope="scope">
            <el-input :value ="scope.row.icon|show"></el-input>
          </template>
        </el-table-column>
      </el-table>
    </template>
    <script>
      export default {
        filters: {
          show (item) {
            return `<mt-bank-icon icon ="${item}"></mt-bank-icon> `
          }
        },
        methods: {
        },
        data () {
          return {
            list: [
              {name: '中国工商银行', icon: 'gongshang'},
              {name: '中国农业银行', icon: 'nongye'},
              {name: '中国银行', icon: 'zhongguo'},
              {name: '中国建设银行', icon: 'jianshe'},
              {name: '交通银行', icon: 'jiaotong'},
              {name: '中信银行', icon: 'zhongxin'},
              {name: '中国光大银行', icon: 'guangda'},
              {name: '华夏银行', icon: 'huaxia'},
              {name: '中国民生银行', icon: 'minsheng'},
              {name: '广发银行', icon: 'guangfa'},
              {name: '深圳发展银行', icon: 'shenzhenfazhan'},
              {name: '招商银行', icon: 'zhaoshang'},
              {name: '兴业银行', icon: 'xingye'},
              {name: '上海浦东发展银行', icon: 'pufa'},
              {name: '恒丰银行', icon: 'hengfeng'},
              {name: '浙商银行', icon: 'zheshang'},
              {name: '渤海银行', icon: 'bohai'},
              {name: '中国邮政储蓄银行', icon: 'youzheng'}
            ]
          }
        }
      }
    </script>
  *
  *
  */

import MtBankIcon from './mt-bank-icon.vue'
export default function install (Vue) {
  Vue.component('mt-bank-icon', MtBankIcon)
}
